@@ -8,7 +8,7 @@ use 5.006;
 use File::Spec ();
 use Config;
 
-our $VERSION = '2.000_000'; # 2.0.0
+our $VERSION = '2.000_001'; # 2.0.1
 $VERSION = eval $VERSION;
 
 sub import {
@@ -380,7 +380,7 @@ sub build_bourne_env_declaration {
   $value =~ s/(^|\G|$_path_sep)\$$name$_path_sep/$1\$$name\${$name+$_path_sep}/g;
   $value =~ s/$_path_sep\$$name$/\${$name+$_path_sep}\$$name/;
 
-  qq{export ${name}="$value";\n}
+  qq{${name}="$value";\nexport ${name};\n}
 }
 
 sub build_csh_env_declaration {
@@ -1260,6 +1260,18 @@ version inside the local::lib will be ignored.  A workaround for this is using
 C<use lib "$ENV{HOME}/perl5/lib/perl5";> inside the script instead of using
 C<local::lib> directly.
 
+=item * Conflicts with L<ExtUtils::MakeMaker>'s C<PREFIX> option.
+C<local::lib> uses the C<INSTALL_BASE> option, as it has more predictable and
+sane behavior.  If something attempts to use the C<PREFIX> option when running
+a F<Makefile.PL>, L<ExtUtils::MakeMaker> will refuse to run, as the two
+options conflict.  This can be worked around by temporarily unsetting the
+C<PERL_MM_OPT> environment variable.
+
+=item * Conflicts with L<Module::Build>'s C<--prefix> option.  Similar to the
+previous limitation, but any C<--prefix> option specified will be ignored.
+This can be worked around by temporarily unsetting the C<PERL_MB_OPT>
+environment variable.
+
 =back
 
 Patches very much welcome for any of the above.
